@@ -20,7 +20,7 @@
 #include "dictionary.h"
 #include <QtGui>
 
-#define USERDICT_FILE "user.idc"
+#define USERDICT_FILE "user_"
 #define SYMBOL_FILE "/basekey.txt"
 #define DATA_PATH "/data/"
 #define WORD_SEPARATOR ';'
@@ -45,7 +45,23 @@ int dictionary::init()
 {
     QString sDictFilePath = QApplication::applicationDirPath() + DATA_PATH + *m_sLanguage;
     QFile *fDict = new QFile(sDictFilePath);
-    QString sUserFilePath = QApplication::applicationDirPath() + DATA_PATH + USERDICT_FILE;
+
+    //This part manage the renaming of user dictionary file//////////
+    QString sOldUserFilePath = QApplication::applicationDirPath() + DATA_PATH + "user.idc";
+    QFile *fOldUserDict = new QFile(sOldUserFilePath);
+    if(fOldUserDict->exists())
+    {
+        QDir dir (QApplication::applicationDirPath() + DATA_PATH);
+        QFileInfo fInfo(*fOldUserDict);
+        QString fPath = fInfo.absoluteFilePath();
+        QString fPath_ren = fPath;
+        fPath_ren.chop(4);
+        fPath_ren += "_" + *m_sLanguage;
+        dir.rename(fPath, fPath_ren);
+    }
+    //////////////////////////////////////////////////////////////////
+
+    QString sUserFilePath = QApplication::applicationDirPath() + DATA_PATH + USERDICT_FILE + *m_sLanguage;
     QFile *fUserDict = new QFile(sUserFilePath);
 
     if(fDict->exists())
@@ -152,7 +168,9 @@ QList<QString> dictionary::getWordList(QString *key)
 /** Save all m_dict hashMap to custom user file, preserving words order **/
 void dictionary::saveDictionaryToFile()
 {
-    QString sDictFilePath = QApplication::applicationDirPath() + DATA_PATH + USERDICT_FILE;
+    qDebug() << "Saving dictionary";
+
+    QString sDictFilePath = QApplication::applicationDirPath() + DATA_PATH + USERDICT_FILE + *m_sLanguage;
     QFile *fDict = new QFile(sDictFilePath);
 
     fDict->remove();
@@ -288,3 +306,15 @@ bool dictionary::isSymbol(QChar car)
     QString sVal = QString(car);
     return m_hmTranslater->contains(sVal,"1");
 }
+
+dictionary::~dictionary()
+{
+    m_dict->clear();
+    delete m_dict;
+    m_hmTranslater->clear();
+    delete m_hmTranslater;
+    m_sLanguage->clear();
+    delete m_sLanguage;
+    m_userDict->clear();
+    delete m_userDict;
+}
