@@ -39,11 +39,15 @@
 
 #define SETTING_LANGUAGE "language"
 #define SETTING_ORIENTATION "orientation"
+#define SETTING_PHONEBOOK "phonebook"
 
 #define ORIENTATION_AUTO "auto"
 #define ORIENTATION_LANDSCAPE "landscape"
 #define ORIENTATION_PORTRAIT "portrait"
 
+#define PHONEBOOK_HORIZONTALCALL 0
+#define PHONEBOOK_MYCONTACTS 1
+
 #define BUTTON_CURNEXT "bt_cur_next"
 #define BUTTON_CURPREV "bt_cur_prev"
 
@@ -65,9 +69,12 @@ fastsms::fastsms(QWidget *parent) :
     Button *send = createButton(tr("Send"),SLOT(sendSMS()));
     Button *btMoveCurNext = createButton(tr("->"),SLOT(moveCursorBt()));
     btMoveCurNext->setObjectName(BUTTON_CURNEXT);
+    btMoveCurNext->setAutoRepeat(true);
     Button *btMoveCurPrev = createButton(tr("<-"),SLOT(moveCursorBt()));
     btMoveCurPrev->setObjectName(BUTTON_CURPREV);
+    btMoveCurPrev->setAutoRepeat(true);
     Button *delChar = createButton(tr("C"),SLOT(deleteChar()));
+    delChar->setAutoRepeat(true);
     Button *one = createButton(tr("1 .,!"),SLOT(digitClicked()));
     Button *two = createButton(tr("2 abc"),SLOT(digitClicked()));
     Button *three = createButton(tr("3 def"),SLOT(digitClicked()));
@@ -78,8 +85,10 @@ fastsms::fastsms(QWidget *parent) :
     Button *eight = createButton(tr("8 tuv"),SLOT(digitClicked()));
     Button *nine = createButton(tr("9 wxyz"),SLOT(digitClicked()));
     Button *zero = createButton(tr("0"),SLOT(digitClicked()));
-    Button *number = createButton(tr("Next"),SLOT(nextWord()));
-    Button *star = createButton(tr("Prev"),SLOT(prevWord()));
+    Button *btNext = createButton(tr("Next"),SLOT(nextWord()));
+    btNext->setAutoRepeat(true);
+    Button *btPrev = createButton(tr("Prev"),SLOT(prevWord()));
+    btPrev->setAutoRepeat(true);
 
     m_phoneNumber = new QLineEdit();
     m_smsEdit = new QTextEdit();
@@ -103,9 +112,9 @@ fastsms::fastsms(QWidget *parent) :
     keyboard->addWidget(seven,3,0);
     keyboard->addWidget(eight,3,1);
     keyboard->addWidget(nine,3,2);
-    keyboard->addWidget(number,4,0);
+    keyboard->addWidget(btNext,4,0);
     keyboard->addWidget(zero,4,1);
-    keyboard->addWidget(star,4,2);
+    keyboard->addWidget(btPrev,4,2);
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
@@ -169,9 +178,11 @@ void fastsms::loadDict()
 {
     bool bOpenOpt = true;
 
-    if(m_settings->contains(SETTING_LANGUAGE))
+    QString sLang = m_settings->value(SETTING_LANGUAGE,"").toString();
+
+    if(!sLang.isEmpty())
     {
-        QString sPath = QApplication::applicationDirPath() + DATA_PATH + m_settings->value(SETTING_LANGUAGE).toString();
+        QString sPath = QApplication::applicationDirPath() + DATA_PATH + sLang;
         QFile *dictFile = new QFile(sPath);
 
         if(dictFile->exists())
@@ -203,7 +214,7 @@ void fastsms::openOptionDialog()
     m_dialOptions->setAttribute(Qt::WA_DeleteOnClose);
     m_uiOptions.setupUi(m_dialOptions);
 
-    connect(m_uiOptions.done,SIGNAL(clicked()),this,SLOT(closeOptions()));
+    connect(m_uiOptions.save,SIGNAL(clicked()),this,SLOT(closeOptions()));
 
     QDir dictDir(QApplication::applicationDirPath() + "/data");
     QStringList dictList = dictDir.entryList(QStringList("*.idc"));
@@ -211,10 +222,13 @@ void fastsms::openOptionDialog()
     QString sCurrLang = m_settings->value(SETTING_LANGUAGE).toString();
     for(int i=0; i<dictList.size(); i++)
     {
-        m_uiOptions.cbLanguage->addItem(dictList.at(i));
+        if(!dictList.at(i).contains("user"))
+        {
+            m_uiOptions.cbLanguage->addItem(dictList.at(i));
 
-        if(dictList.at(i).compare(sCurrLang) == 0)
-            m_uiOptions.cbLanguage->setCurrentIndex(i);
+            if(dictList.at(i).compare(sCurrLang) == 0)
+                m_uiOptions.cbLanguage->setCurrentIndex(i);
+        }
     }
 
     m_uiOptions.orientationAuto->setChecked(true);
@@ -225,6 +239,9 @@ void fastsms::openOptionDialog()
     else if(sCurrOrient.compare(ORIENTATION_PORTRAIT) == 0)
         m_uiOptions.orientationPortrait->setChecked(true);
 
+    int nPhoneBook = m_settings->value(SETTING_PHONEBOOK).toInt();
+    m_uiOptions.cbPhonebook->setCurrentIndex(nPhoneBook);
+
     m_dialOptions->show();
 }
 
@@ -251,6 +268,7 @@ void fastsms::closeOptions()
 
     QString sDictFile = m_uiOptions.cbLanguage->currentText();
     m_settings->setValue(SETTING_LANGUAGE,sDictFile);
+    m_settings->setValue(SETTING_PHONEBOOK,m_uiOptions.cbPhonebook->currentIndex());
 
     if(m_uiOptions.orientationAuto->isChecked())
     {
@@ -277,6 +295,9 @@ void fastsms::closeOptions()
     if(sOldLang.compare(sDictFile) != 0)
     {
         qDebug() << "Language changed!";
+        if(m_bNeedSave)
+            m_dict->saveDictionaryToFile();
+
         delete m_dict;
         m_dict = new dictionary(new QString(m_settings->value(SETTING_LANGUAGE).toString()),this);
     }
@@ -307,7 +328,7 @@ void fastsms::moveCursorBt()
         else
             m_nEndWord = m_nBeginWord;
 
-        lWord.clear();
+        m_lWord.clear();
         m_sCompleteValue.clear();
         m_nWordIndex=0;
 
@@ -320,7 +341,7 @@ void fastsms::moveCursorBt()
     {
         m_smsEdit->disconnect();
 
-        lWord.clear();
+        m_lWord.clear();
         m_sCompleteValue.clear();
         m_nWordIndex=0;
 
@@ -372,10 +393,10 @@ void fastsms::cursorPosChanged()
             qDebug() << "Selected text from Cursor moved" << m_cursorSmsText.selectedText().toAscii();
 
             QString *sWord = new QString(m_cursorSmsText.selectedText());
-            m_sCompleteValue = *m_dict->calculateKey(sWord);            
-            lWord = m_dict->getWordList(&m_sCompleteValue);
+            m_sCompleteValue = *m_dict->calculateKey(sWord);
+            m_lWord = m_dict->getWordList(&m_sCompleteValue);
             //m_nWordIndex = 0;
-            m_nWordIndex = lWord.indexOf(*sWord);
+            m_nWordIndex = m_lWord.indexOf(*sWord);
             if(m_nWordIndex < 0)
                 m_nWordIndex = 0;
             m_nState = STATE_AFTERCURMOVED;
@@ -387,7 +408,7 @@ void fastsms::cursorPosChanged()
             qDebug() << "Nothing selected";
             m_sCompleteValue.clear();
             m_nWordIndex = 0;
-            lWord.clear();
+            m_lWord.clear();
         }
 
         connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
@@ -441,12 +462,12 @@ void fastsms::digitClicked()
             m_nMsgLength++;
             m_sCompleteValue = lastPress;
             m_nWordIndex=0;
-            lWord.clear();
-            lWord = m_dict->getWordList(&m_sCompleteValue);
+            m_lWord.clear();
+            m_lWord = m_dict->getWordList(&m_sCompleteValue);
 
             m_nEndWord ++;
             m_nBeginWord = m_nEndWord-1;
-            QString sChoosenWord = lWord.at(0);
+            QString sChoosenWord = m_lWord.at(0);
             addText(sChoosenWord);
             m_sCompleteValue.clear();
 
@@ -469,10 +490,10 @@ void fastsms::digitClicked()
                 m_nState = STATE_WORD;
                 m_nMsgLength++;
                 m_nWordIndex=0;
-                lWord = m_dict->getWordList(&m_sCompleteValue);
+                m_lWord = m_dict->getWordList(&m_sCompleteValue);
 
                 m_nEndWord++;
-                QString sChoosenWord = lWord.at(0);
+                QString sChoosenWord = m_lWord.at(0);
                 updateText(sChoosenWord);
             }
             else
@@ -485,11 +506,11 @@ void fastsms::digitClicked()
                     m_sCompleteValue = lastPress;
 
                     m_nWordIndex=0;
-                    lWord = m_dict->getWordList(&m_sCompleteValue);
+                    m_lWord = m_dict->getWordList(&m_sCompleteValue);
 
                     m_nBeginWord = m_nEndWord;
                     m_nEndWord ++;
-                    QString sChoosenWord = lWord.at(0);
+                    QString sChoosenWord = m_lWord.at(0);
                     addText(sChoosenWord);
                 }
                 else
@@ -502,11 +523,11 @@ void fastsms::digitClicked()
                         m_sCompleteValue = lastPress;
 
                         m_nWordIndex=0;
-                        lWord = m_dict->getWordList(&m_sCompleteValue);
+                        m_lWord = m_dict->getWordList(&m_sCompleteValue);
 
                         m_nBeginWord = m_nEndWord;
                         m_nEndWord ++;
-                        QString sChoosenWord = lWord.at(0);
+                        QString sChoosenWord = m_lWord.at(0);
                         addText(sChoosenWord);
 
                     }
@@ -524,27 +545,27 @@ void fastsms::digitClicked()
 
 void fastsms::nextWord()
 {
-    if(lWord.count() > 0)
+    if(m_lWord.count() > 0)
     {
         m_nWordIndex++;
 
-        if(m_nWordIndex >= lWord.count())
+        if(m_nWordIndex >= m_lWord.count())
             m_nWordIndex = 0;
 
-        updateText(lWord.at(m_nWordIndex));
+        updateText(m_lWord.at(m_nWordIndex));
     }
 }
 
 void fastsms::prevWord()
 {
-    if(lWord.count() > 0)
+    if(m_lWord.count() > 0)
     {
         m_nWordIndex--;
 
         if(m_nWordIndex < 0)
-            m_nWordIndex = lWord.count() - 1;
+            m_nWordIndex = m_lWord.count() - 1;
 
-        updateText(lWord.at(m_nWordIndex));
+        updateText(m_lWord.at(m_nWordIndex));
     }
 }
 
@@ -578,8 +599,8 @@ void fastsms::newWordInserted()
 
         m_sCompleteValue.clear();
         m_sCompleteValue.append(m_dict->calculateKey(newWord));
-        lWord = m_dict->getWordList(&m_sCompleteValue);
-        m_nWordIndex=lWord.indexOf(*newWord);
+        m_lWord = m_dict->getWordList(&m_sCompleteValue);
+        m_nWordIndex=m_lWord.indexOf(*newWord);
 
         updateText(*newWord);
     }
@@ -638,25 +659,52 @@ void fastsms::deleteChar()
 
 void fastsms::openPhoneBook()
 {
-    QDBusMessage msg = QDBusMessage::createMethodCall(
-        "com.crochik.MyContacts", // --dest
-        "/", // destination object path
-        "com.crochik.MyContacts",
-        "show"
-    );
-    msg << "Opening Mycontacts";
-    msg = QDBusConnection::sessionBus().call(msg);
-    qDebug() << msg;
-    bool ok = msg.type() != QDBusMessage::ErrorMessage;
+    bool ok = false;
+    int Pb = m_settings->value(SETTING_PHONEBOOK).toInt();
+
+
+
+    if(Pb == PHONEBOOK_MYCONTACTS)
+    {
+        QDBusMessage msg = QDBusMessage::createMethodCall(
+                "com.crochik.MyContacts", // --dest
+                "/", // destination object path
+                "com.crochik.MyContacts",
+                "select_phone"
+                );
+
+        msg << "Opening Mycontacts";
+        QList<QVariant> args;
+        args.append("FastSMS");
+        msg.setArguments(args);
+        msg = QDBusConnection::sessionBus().call(msg);
+        qDebug() << msg;
+        ok = msg.type() != QDBusMessage::ErrorMessage;
+    }
+
+    else if((Pb) == PHONEBOOK_HORIZONTALCALL)
+    {        
+        QDBusMessage msg = QDBusMessage::createMethodCall(
+                "com.eitam.horizontalcall", // --dest
+                "/com/eitam/horizontalcall", // destination object path
+                "com.eitam.horizontalcall", // message name (w/o method)
+                "top_application" // method
+                );
+
+        msg = QDBusConnection::sessionBus().call(msg);
+        qDebug() << msg;
+        ok = msg.type() != QDBusMessage::ErrorMessage;
+    }
 
     if(!ok)
     {
         QDialog *dlCont = new QDialog(this);
         dlCont->setAttribute(Qt::WA_DeleteOnClose);
 
-        dlCont->setWindowTitle("Can't open Mycontacts");
+        dlCont->setWindowTitle("Can't open selected phonebook");
         QGridLayout *layout = new QGridLayout();
-        QString sInfo = QString("\nYou need to install MyContacts\nto use this feature!!!\n");
+        QString sInfo = QString("\nYou need to install the selected phonebook to use this feature!!!\n"
+                                "You can change default phonebook in Option Menu.");
         QLabel *msg = new QLabel(sInfo);
         layout->addWidget(msg,0,0);
         dlCont->setLayout(layout);
@@ -672,7 +720,7 @@ void fastsms::sendSMS()
     //Find right account for SMS: default one doesnt work well
     QMessageAccountIdList lstMsgAccountId = manager.queryAccounts();
 
-    if(!m_smsEdit->toPlainText().isEmpty())
+    if(!m_smsEdit->toPlainText().isEmpty() && !m_phoneNumber->text().isEmpty())
     {
         if(!lstMsgAccountId.isEmpty())
         {
@@ -704,7 +752,7 @@ void fastsms::sendSMS()
     m_smsEdit->clear();
     m_sCompleteValue.clear();
     m_phoneNumber->clear();
-    lWord.clear();
+    m_lWord.clear();
     m_nWordIndex=0;
 
     connect(m_smsEdit,SIGNAL(textChanged()),this,SLOT(smsChanged()));
@@ -715,14 +763,18 @@ void fastsms::saveDictionaryOnExit()
 {
     if(m_bNeedSave)
     {
-        qDebug() << "Saving dictionary";
         m_dict->saveDictionaryToFile();
     }
 }
 
 bool fastsms::addRecipient(const QString &phone, const QString &name)
 {
+    m_phoneNumber->clear();
     m_phoneNumber->setText(phone);
+
+    this->activateWindow();
+    this->raise();
+
     return true;
 }
 
@@ -750,7 +802,6 @@ fastsms::~fastsms()
 {
     //delete ui;
     //delete m_sCompleteValue;
-
 }
 
 void fastsms::changeEvent(QEvent *e)
