@@ -38,7 +38,7 @@ class fastsms : public QWidget
 public:
     explicit fastsms(QWidget *parent = 0);
     ~fastsms();
-    QList<QString> lWord;
+    QList<QString> m_lWord;
     QTextEdit *m_smsEdit;
     QLineEdit *m_phoneNumber;
     dictionary *m_dict;
